use chromium::rocket::Chromium;
use nanobyte_opentelemetry::rocket::TracingFairing;
use rocket::{Rocket, Build, routes, fairing::AdHoc};
use serde::Deserialize;
pub mod routes;
mod chromium;
mod tools;
mod services;



#[derive(Deserialize)]
#[serde(crate = "rocket::serde")]
pub struct CVBackendConfig {
    cv_backend_path: String,
}


#[derive(Deserialize)]
#[serde(crate = "rocket::serde")]
#[allow(dead_code)]
pub struct DefaultPerson {
    pub(crate) default_person_name: String,
}

pub fn rocket_builder() -> Rocket<Build> {
    rocket::build()
        .attach(TracingFairing::ignite())
        .attach(Chromium::ignite())
        .attach(
            AdHoc::config::<CVBackendConfig>()
        )
        .attach(
            AdHoc::config::<DefaultPerson>()
        )
        .mount("/", routes![
            routes::pdf::render_pdf_cv,
            routes::pdf::render_html_cv
        ])
}
